@@ -22,7 +22,7 @@ class Filesystem(IOSExtraction):
         file_path: Optional[str] = None,
         target_path: Optional[str] = None,
         results_path: Optional[str] = None,
-        fast_mode: bool = False,
+        module_options: Optional[dict] = None,
         log: logging.Logger = logging.getLogger(__name__),
         results: Optional[list] = None,
     ) -> None:
@@ -30,7 +30,7 @@ class Filesystem(IOSExtraction):
             file_path=file_path,
             target_path=target_path,
             results_path=results_path,
-            fast_mode=fast_mode,
+            module_options=module_options,
             log=log,
             results=results,
         )
@@ -57,7 +57,7 @@ class Filesystem(IOSExtraction):
                 self.detected.append(result)
 
             # If we are instructed to run fast, we skip the rest.
-            if self.fast_mode:
+            if self.module_options.get("fast_mode", None):
                 continue
 
             ioc = self.indicators.check_file_path_process(result["path"])
